@@ -24,8 +24,8 @@ are_equivalent_xml_files <- function(
   filename_2,
   section = NA
 ) {
-  beautier::check_file_exists(filename_1, "filename_1")
-  beautier::check_file_exists(filename_2, "filename_2")
+  check_file_exists(filename_1, "filename_1")
+  check_file_exists(filename_2, "filename_2")
   are_equivalent_xml_lines(
     readLines(filename_1),
     readLines(filename_2),
@@ -48,18 +48,18 @@ are_equivalent_xml_lines <- function(
   section = NA,
   verbose = FALSE
 ) {
-  if (beautier::is_one_na(section)) {
+  if (is_one_na(section)) {
     return(
-      beautier::are_equivalent_xml_lines_all(
+      are_equivalent_xml_lines_all(
         lines_1 = lines_1,
         lines_2 = lines_2,
         verbose = verbose
       )
     )
   } else {
-    testit::assert(!beautier::is_one_na(section))
+    check_true(!is_one_na(section))
     return(
-      beautier::are_equivalent_xml_lines_section(
+      are_equivalent_xml_lines_section(
         lines_1 = lines_1,
         lines_2 = lines_2,
         section = section,
@@ -129,50 +129,50 @@ are_equivalent_xml_lines_section <- function( # nolint don't care about internal
   section,
   verbose = FALSE
 ) {
-  assertive::assert_is_a_string(section)
+  check_string(section)
   if (section == "operators") {
     return(
-      beautier::are_equivalent_xml_lines_operators(lines_1, lines_2, verbose)
+      are_equivalent_xml_lines_operators(lines_1, lines_2, verbose)
     )
   }
   if (section == "loggers") {
     return(
-      beautier::are_equivalent_xml_lines_loggers(lines_1, lines_2, verbose)
+      are_equivalent_xml_lines_loggers(lines_1, lines_2, verbose)
     )
   }
-  if (!beautier::has_xml_opening_tag(lines = lines_1, section = section)) {
+  if (!has_xml_opening_tag(lines = lines_1, section = section)) {
     stop(
       "Opening tag for 'section' could not be found in 'lines_1', ",
       "'section' has value '", section, "'"
     )
   }
-  if (!beautier::has_xml_closing_tag(lines = lines_1, section = section)) {
+  if (!has_xml_closing_tag(lines = lines_1, section = section)) {
     stop(
       "Closing tag for 'section' could not be found in 'lines_1', ",
       "'section' has value '", section, "'"
     )
   }
-  if (!beautier::has_xml_opening_tag(lines = lines_2, section = section)) {
+  if (!has_xml_opening_tag(lines = lines_2, section = section)) {
     stop(
       "Opening tag for 'section' could not be found in 'lines_2', ",
       "'section' has value '", section, "'"
     )
   }
-  if (!beautier::has_xml_closing_tag(lines = lines_2, section = section)) {
+  if (!has_xml_closing_tag(lines = lines_2, section = section)) {
     stop(
       "Closing tag for 'section' could not be found in 'lines_2', ",
       "'section' has value '", section, "'"
     )
   }
-  section_1 <- beautier::extract_xml_section_from_lines(
+  section_1 <- extract_xml_section_from_lines(
     lines = lines_1,
     section = section
   )
-  section_2 <- beautier::extract_xml_section_from_lines(
+  section_2 <- extract_xml_section_from_lines(
     lines = lines_2,
     section = section
   )
-  beautier::are_equivalent_xml_lines_all(
+  are_equivalent_xml_lines_all(
     section_1,
     section_2,
     verbose = verbose
@@ -192,9 +192,9 @@ are_equivalent_xml_lines_operators <- function( # nolint indeed long function na
   lines_2,
   verbose = FALSE
 ) {
-  section_1 <- beautier::extract_xml_operators_from_lines(lines_1)
-  section_2 <- beautier::extract_xml_operators_from_lines(lines_2)
-  beautier::are_equivalent_xml_lines_all(
+  section_1 <- extract_xml_operators_from_lines(lines_1)
+  section_2 <- extract_xml_operators_from_lines(lines_2)
+  are_equivalent_xml_lines_all(
     section_1, section_2, verbose = verbose
   )
 }
@@ -212,9 +212,9 @@ are_equivalent_xml_lines_loggers <- function(# nolint don't care about internal
   lines_2,
   verbose = FALSE
 ) {
-  section_1 <- beautier::extract_xml_loggers_from_lines(lines_1)
-  section_2 <- beautier::extract_xml_loggers_from_lines(lines_2)
-  beautier::are_equivalent_xml_lines_all(
+  section_1 <- extract_xml_loggers_from_lines(lines_1)
+  section_2 <- extract_xml_loggers_from_lines(lines_2)
+  are_equivalent_xml_lines_all(
     section_1,
     section_2,
     verbose = verbose
