@@ -7,12 +7,12 @@
 are_mrca_priors <- function(
   mrca_priors
 ) {
-  if (beautier::is_one_na(mrca_priors)) return(TRUE)
+  if (is_one_na(mrca_priors)) return(TRUE)
   if (!is.list(mrca_priors)) return(FALSE)
   for (i in seq_along(mrca_priors)) {
     mrca_prior <- mrca_priors[[i]]
     tryCatch(
-      beautier::check_mrca_prior(mrca_prior),
+      check_mrca_prior(mrca_prior),
       error = function(e) return(FALSE) # nolint indeed ignore e
     )
   }
