@@ -9,10 +9,10 @@ b_pop_sizes_param_to_xml <- function(
   b_pop_sizes_param,
   beauti_options = create_beauti_options()
 ) {
-  beautier::check_beauti_options(beauti_options)
-  testit::assert(beautier::is_b_pop_sizes_param(b_pop_sizes_param))
+  check_beauti_options(beauti_options)
+  check_true(is_b_pop_sizes_param(b_pop_sizes_param))
   id <- b_pop_sizes_param$id
-  testit::assert(beautier::is_id(id))
+  check_true(is_id(id))
 
   xml <- paste0(
     "<parameter id=\"bPopSizes.t:", id, "\" ",
