@@ -43,12 +43,12 @@
 create_branch_rate_model_xml <- function(# nolint long function name, which is fine for a long function
   inference_model
 ) {
-  if (beautier::is_strict_clock_model(inference_model$clock_model)) {
-    return(beautier::create_strict_clock_branch_rate_model_xml(inference_model))
+  if (is_strict_clock_model(inference_model$clock_model)) {
+    return(create_strict_clock_branch_rate_model_xml(inference_model))
   } else {
-    testthat::expect_true(
-      beautier::is_rln_clock_model(inference_model$clock_model)
+    check_true(
+      is_rln_clock_model(inference_model$clock_model)
     )
-    return(beautier::create_rln_clock_branch_rate_model_xml(inference_model))
+    return(create_rln_clock_branch_rate_model_xml(inference_model))
   }
 }
