@@ -16,7 +16,7 @@
 #' @export
 create_clock_models <- function() {
   list(
-    beautier::create_rln_clock_model(),
-    beautier::create_strict_clock_model()
+    create_rln_clock_model(),
+    create_strict_clock_model()
   )
 }
