@@ -13,6 +13,7 @@
 #'  </logger>
 #' }
 #' @inheritParams default_params_doc
+#' @return lines of XML text
 #' @seealso
 #' Use \link{create_tracelog_xml} to create the XML text
 #' of the logger with the \code{tracelog} ID.
@@ -26,23 +27,23 @@ create_loggers_xml <- function(
   input_filename,
   inference_model
 ) {
-  testit::assert(length(input_filename) == 1)
-  beautier::check_inference_model(inference_model)
+  check_true(length(input_filename) == 1)
+  check_inference_model(inference_model)
 
-  tracelog_text <- beautier::create_tracelog_xml(
+  tracelog_text <- create_tracelog_xml(
     input_filename = input_filename,
     inference_model = inference_model
   )
 
-  screenlog_text <- beautier::create_screenlog_xml(inference_model)
+  screenlog_text <- create_screenlog_xml(inference_model)
 
-  treelogs_text <- beautier::create_treelog_xml(inference_model)
+  treelogs_text <- create_treelog_xml(inference_model)
 
 
   c(
-    beautier::indent(tracelog_text),
+    indent(tracelog_text),
     "",
-    beautier::indent(screenlog_text),
-    beautier::indent(treelogs_text)
+    indent(screenlog_text),
+    indent(treelogs_text)
   )
 }
