@@ -6,6 +6,7 @@
 #' </logger>
 #' ```
 #' @inheritParams default_params_doc
+#' @return lines of XML text
 #' @author Richèl J.C. Bilderbeek
 #' @export
 create_treelog_xml <- function(
@@ -38,8 +39,8 @@ create_treelog_xml <- function(
   text <- c(text, top_line)
   text <- c(
     text,
-    beautier::indent(
-      beautier::clock_model_to_xml_treelogger(
+    indent(
+      clock_model_to_xml_treelogger(
         inference_model$clock_model
       )
     )
