@@ -6,11 +6,11 @@
 extract_xml_operators_from_lines <- function(# nolint indeed a long function name
   lines
 ) {
-  first_line <- beautier::find_first_regex_line(lines, "<operator id=\"")
-  if (beautier::is_one_na(first_line)) {
+  first_line <- find_first_regex_line(lines, "<operator id=\"")
+  if (is_one_na(first_line)) {
     return("")
   }
-  last_line <- beautier::find_last_regex_line(
+  last_line <- find_last_regex_line(
     lines,
     "(<operator id=\")|(</operator>)"
   )
