@@ -10,11 +10,11 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 fasta_file_to_sequences <- function(fasta_filename) {
-  beautier::check_file_exists(fasta_filename, "fasta_filename")
+  check_file_exists(fasta_filename, "fasta_filename")
 
   # Read the file
   sequences_dnabin <- ape::read.FASTA(fasta_filename)
-  testit::assert(class(sequences_dnabin) == "DNAbin")
+  check_true(class(sequences_dnabin) == "DNAbin")
 
   # Convert the file to a table with labels and sequences
   labels <- names(sequences_dnabin)
