@@ -14,7 +14,7 @@ freq_equilibrium_to_xml <- function(
   freq_equilibrium,
   id
 ) {
-  testit::assert(beautier::is_freq_equilibrium_name(freq_equilibrium))
+  check_true(is_freq_equilibrium_name(freq_equilibrium))
   if (freq_equilibrium == "estimated") {
     paste0("<frequencies ", "id=\"estimatedFreqs.s:", id, "\" ",
       "spec=\"Frequencies\" ",
@@ -25,7 +25,7 @@ freq_equilibrium_to_xml <- function(
       "spec=\"Frequencies\" data=\"@", id, "\"/>" # nolint this is no absolute path
     )
   } else {
-    testit::assert(freq_equilibrium == "all_equal")
+    check_true(freq_equilibrium == "all_equal")
     paste0("<frequencies id=\"equalFreqs.s:", id, "\" ",
       "spec=\"Frequencies\" data=\"@", id, "\" estimate=\"false\"/>") # nolint this is no absolute path
   }
