@@ -23,7 +23,7 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_gamma_site_model_n_distrs <- function(gamma_site_model) {
-  testit::assert(beautier::is_gamma_site_model(gamma_site_model))
+  check_true(is_gamma_site_model(gamma_site_model))
   if (gamma_site_model$gamma_cat_count < 2) {
     0
   } else {
