@@ -28,10 +28,10 @@
 get_gamma_site_model_n_params <- function(
   gamma_site_model
 ) {
-  testit::assert(beautier::is_gamma_site_model(gamma_site_model))
+  check_true(is_gamma_site_model(gamma_site_model))
   if (gamma_site_model$gamma_cat_count < 2) {
     0
   } else {
-    beautier::get_distr_n_params(gamma_site_model$gamma_shape_prior_distr)
+    get_distr_n_params(gamma_site_model$gamma_shape_prior_distr)
   }
 }
