@@ -5,9 +5,9 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_has_non_strict_clock_model <- function(clock_models) {
-  testit::assert(beautier::are_clock_models(clock_models))
+  check_true(are_clock_models(clock_models))
   for (clock_model in clock_models) {
-    if (!beautier::is_strict_clock_model(clock_model)) {
+    if (!is_strict_clock_model(clock_model)) {
       return(TRUE)
     }
   }
