@@ -13,19 +13,19 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_operator_id_pre <- function(tree_prior) {
-  if (beautier::is_bd_tree_prior(tree_prior)) {
+  if (is_bd_tree_prior(tree_prior)) {
     return("BirthDeath")
   }
-  if (beautier::is_cbs_tree_prior(tree_prior)) {
+  if (is_cbs_tree_prior(tree_prior)) {
     return("BayesianSkyline")
   }
-  if (beautier::is_ccp_tree_prior(tree_prior)) {
+  if (is_ccp_tree_prior(tree_prior)) {
     return("CoalescentConstant")
   }
-  if (beautier::is_cep_tree_prior(tree_prior)) {
+  if (is_cep_tree_prior(tree_prior)) {
     return("CoalescentExponential")
   }
-  if (beautier::is_yule_tree_prior(tree_prior)) {
+  if (is_yule_tree_prior(tree_prior)) {
     return("YuleModel")
   }
   stop("Unknown tree prior")
