@@ -22,21 +22,21 @@
 get_site_model_n_distrs <- function(
   site_model
 ) {
-  if (!beautier::is_site_model(site_model)) {
+  if (!is_site_model(site_model)) {
     stop("'site_model' must be a site model")
   }
   gamma_site_model <- site_model$gamma_site_model
-  gamma_site_model_n_distrs <- beautier::get_gamma_site_model_n_distrs(
+  gamma_site_model_n_distrs <- get_gamma_site_model_n_distrs(
     gamma_site_model
   )
-  if (beautier::is_gtr_site_model(site_model)) {
+  if (is_gtr_site_model(site_model)) {
     return(5 + gamma_site_model_n_distrs)
-  } else if (beautier::is_hky_site_model(site_model)) {
+  } else if (is_hky_site_model(site_model)) {
     return(1 + gamma_site_model_n_distrs)
-  } else if (beautier::is_jc69_site_model(site_model)) {
+  } else if (is_jc69_site_model(site_model)) {
     return(0 + gamma_site_model_n_distrs)
   } else {
-    testit::assert(beautier::is_tn93_site_model(site_model))
+    check_true(is_tn93_site_model(site_model))
     return(2 + gamma_site_model_n_distrs)
   }
 }
