@@ -21,6 +21,6 @@
 #' check_empty_beautier_folder()
 #' @export
 has_strict_clock_model <- function(inference_model) {
-  beautier::check_inference_model(inference_model)
-  beautier::is_strict_clock_model(inference_model$clock_model)
+  check_inference_model(inference_model)
+  is_strict_clock_model(inference_model$clock_model)
 }
