@@ -11,9 +11,9 @@ has_xml_closing_tag <- function(
   lines,
   section
 ) {
-  assertive::assert_is_a_string(section)
-  !beautier::is_one_na(
-    beautier::find_last_xml_closing_tag_line(
+  check_string(section)
+  !is_one_na(
+    find_last_xml_closing_tag_line(
       lines = lines,
       section = section
     )
