@@ -24,19 +24,19 @@ init_gamma_site_model <- function(
   distr_id = 0,
   param_id = 0
 ) {
-  testit::assert(beautier::is_gamma_site_model(gamma_site_model))
+  check_true(is_gamma_site_model(gamma_site_model))
 
-  if (!beautier::is_init_distr(gamma_site_model$gamma_shape_prior_distr)) {
-    gamma_site_model$gamma_shape_prior_distr <- beautier::init_distr(
+  if (!is_init_distr(gamma_site_model$gamma_shape_prior_distr)) {
+    gamma_site_model$gamma_shape_prior_distr <- init_distr(
       gamma_site_model$gamma_shape_prior_distr,
       distr_id = distr_id,
       param_id = param_id
     )
     distr_id <- distr_id + 1
-    param_id <- param_id + beautier::get_distr_n_params(
+    param_id <- param_id + get_distr_n_params(
       gamma_site_model$gamma_shape_prior_distr
     )
   }
-  testit::assert(beautier::is_gamma_site_model(gamma_site_model))
+  check_true(is_gamma_site_model(gamma_site_model))
   gamma_site_model
 }
