@@ -11,9 +11,10 @@ init_mrca_priors <- function(
   param_id = 0,
   beauti_options
 ) {
-  if (length(mrca_priors) == 1 && beautier::is_one_na(mrca_priors)) return(NA)
-  testthat::expect_equal(1, length(mrca_priors))
-  testit::assert(beautier::are_mrca_priors(mrca_priors))
+  if (length(mrca_priors) == 1 && is_one_na(mrca_priors)) return(NA)
+
+  check_true(length(mrca_priors) == 1)
+  check_true(are_mrca_priors(mrca_priors))
   if (beauti_options$beast2_version == "2.4") {
     names <- "auto_name_1"
   } else {
@@ -22,28 +23,28 @@ init_mrca_priors <- function(
 
   for (i in seq_along(mrca_priors)) {
     mrca_prior <- mrca_priors[[i]]
-    testit::assert(beautier::is_mrca_prior(mrca_prior))
+    check_true(is_mrca_prior(mrca_prior))
 
-    if (beautier::is_one_na(mrca_prior$name)) {
+    if (is_one_na(mrca_prior$name)) {
       mrca_prior$name <- names[i]
     }
-    if (beautier::is_one_na(mrca_prior$clock_prior_distr_id)) {
+    if (is_one_na(mrca_prior$clock_prior_distr_id)) {
       mrca_prior$clock_prior_distr_id <- distr_id
       distr_id <- distr_id + 1
     }
-    if (beautier::is_distr(mrca_prior$mrca_distr) &&
-        !beautier::is_init_distr(mrca_prior$mrca_distr)
+    if (is_distr(mrca_prior$mrca_distr) &&
+        !is_init_distr(mrca_prior$mrca_distr)
     ) {
-      mrca_prior$mrca_distr <- beautier::init_distr(
+      mrca_prior$mrca_distr <- init_distr(
         distr = mrca_prior$mrca_distr,
         distr_id = distr_id,
         param_id = param_id
       )
       distr_id <- distr_id + 1
-      param_id <- param_id + beautier::get_distr_n_params(mrca_prior$mrca_distr)
+      param_id <- param_id + get_distr_n_params(mrca_prior$mrca_distr)
     }
 
-    testit::assert(beautier::is_mrca_prior(mrca_prior))
+    check_true(is_mrca_prior(mrca_prior))
     mrca_priors[[i]] <- mrca_prior
   }
   mrca_priors
