@@ -12,5 +12,5 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 is_clock_model_name <- function(name) {
-  name %in% beautier::get_clock_model_names()
+  name %in% get_clock_model_names()
 }
