@@ -16,10 +16,10 @@ kappa_param_to_xml <- function(
   kappa_param,
   beauti_options = create_beauti_options()
 ) {
-  beautier::check_beauti_options(beauti_options)
-  testit::assert(beautier::is_kappa_param(kappa_param))
+  check_beauti_options(beauti_options)
+  check_true(is_kappa_param(kappa_param))
   id <- kappa_param$id
-  testit::assert(beautier::is_id(id))
+  check_true(is_id(id))
 
   xml <- paste0("<parameter id=\"kappa.s:", id, "\" ")
   if (beauti_options$beast2_version == "2.6") {
