@@ -23,13 +23,13 @@ mrca_prior_to_xml_taxonset <- function(
   mrca_prior,
   taxa_names_with_ids = NULL
 ) {
-  testit::assert(beautier::is_mrca_prior(mrca_prior))
+  check_true(is_mrca_prior(mrca_prior))
   text <- NULL
-  testit::assert(!beautier::is_one_na(mrca_prior$taxa_names))
+  check_true(!is_one_na(mrca_prior$taxa_names))
   for (taxon_name in mrca_prior$taxa_names) {
     text <- c(text, paste0("<taxon id=\"", taxon_name, "\" spec=\"Taxon\"/>")) # nolint this is no absolute path
   }
-  text <- beautier::indent(text)
+  text <- indent(text)
   text <- c(
     paste0("<taxonset id=\"", mrca_prior$name, "\" spec=\"TaxonSet\">"),
     text
