@@ -20,12 +20,12 @@
 taxa_to_xml_tree <- function(
   inference_model
 ) {
-  if (beautier::is_one_na(inference_model$tipdates_filename)) {
-    beautier::no_taxa_to_xml_tree(
+  if (is_one_na(inference_model$tipdates_filename)) {
+    no_taxa_to_xml_tree(
       inference_model = inference_model
     )
   } else {
-    beautier::tipdate_taxa_to_xml_tree(
+    tipdate_taxa_to_xml_tree(
       inference_model = inference_model
     )
   }
@@ -54,7 +54,7 @@ no_taxa_to_xml_tree <- function(
   inference_model
 ) {
   id <- inference_model$tree_prior$id
-  testit::assert(beautier::is_id(id))
+  check_true(is_id(id))
   text <- NULL
   if (inference_model$beauti_options$beast2_version == "2.6") {
     text <- c(
@@ -101,8 +101,8 @@ tipdate_taxa_to_xml_tree <- function(
   id <- inference_model$tree_prior$id
   tipdates_filename <- inference_model$tipdates_filename
 
-  testit::assert(beautier::is_id(id))
-  testit::assert(!beautier::is_one_na(tipdates_filename))
+  check_true(is_id(id))
+  check_true(!is_one_na(tipdates_filename))
 
   first_line <- paste0("<tree id=\"Tree.t:", id, "\" ")
   if (inference_model$beauti_options$beast2_version == "2.6") {
@@ -112,8 +112,8 @@ tipdate_taxa_to_xml_tree <- function(
 
   c(
     first_line,
-    beautier::indent(beautier::tipdate_taxa_to_xml_trait(inference_model)),
-    beautier::indent(
+    indent(tipdate_taxa_to_xml_trait(inference_model)),
+    indent(
       paste0(
         "<taxonset idref=\"TaxonSet.",
         inference_model$site_model$id,
