@@ -8,12 +8,12 @@ tn93_site_model_to_xml_state <- function(
   site_model,
   beauti_options = create_beauti_options()
 ) {
-  testit::assert(beautier::is_site_model(site_model))
-  beautier::check_beauti_options(beauti_options)
+  check_true(is_site_model(site_model))
+  check_beauti_options(beauti_options)
   id <- site_model$id
-  testit::assert(beautier::is_id(id))
+  check_true(is_id(id))
   text <- NULL
-  testthat::expect_true(beautier::is_tn93_site_model(site_model))
+  check_true(is_tn93_site_model(site_model))
 
   # Indeed, overwrite by the site model's ID
   site_model$kappa_1_param$id <- id
@@ -24,7 +24,7 @@ tn93_site_model_to_xml_state <- function(
   if (site_model$kappa_1_param$estimate == TRUE) {
     text <- c(
       text,
-      beautier::parameter_to_xml(
+      parameter_to_xml(
         site_model$kappa_1_param,
         beauti_options = beauti_options
       )
@@ -33,7 +33,7 @@ tn93_site_model_to_xml_state <- function(
   if (site_model$kappa_2_param$estimate == TRUE) {
     text <- c(
       text,
-      beautier::parameter_to_xml(
+      parameter_to_xml(
         site_model$kappa_2_param,
         beauti_options = beauti_options
       )
@@ -41,7 +41,7 @@ tn93_site_model_to_xml_state <- function(
   }
   text <- c(
     text,
-    beautier::freq_param_to_xml(
+    freq_param_to_xml(
       site_model$freq_param,
       beauti_options = beauti_options
     )
@@ -49,7 +49,7 @@ tn93_site_model_to_xml_state <- function(
 
   text <- c(
     text,
-    beautier::gamma_site_model_to_xml_state(site_model$gamma_site_model, id)
+    gamma_site_model_to_xml_state(site_model$gamma_site_model, id)
   )
   text
 }
